@@ -6,7 +6,7 @@ class Worker(object):
     def __init__(self, addr, path, **kargs):
         self.tq = TaskQueue(addr, path, **kargs)
 
-    def run(self, clas, *args, **kargs):
+    def run(self, cls, *args, **kargs):
         ins = cls(*args, **kargs)
         while 1:
             task =  self.tq.GET_TASK()
